@@ -991,7 +991,7 @@ class SaleLine(ModelSQL, ModelView):
             states={
                 'invisible': "type not in ('line', 'subtotal')",
                 'readonly': "not globals().get('_parent_sale')",
-            }, on_change_with=['type', 'quantity', 'unit_price',
+            }, on_change_with=['type', 'quantity', 'unit_price', 'unit',
                 '_parent_sale.currency'])
     description = fields.Text('Description', size=None, required=True)
     note = fields.Text('Note')
@@ -1290,6 +1290,8 @@ class SaleLine(ModelSQL, ModelView):
         ignored_ids = set(
             l.id for i in line.sale.invoices_ignored for l in i.lines)
         for invoice_line in line.invoice_lines:
+            if invoice_line.type != 'line':
+                continue
             if ((invoice_line.invoice and
                     invoice_line.invoice.state != 'cancel') or
                 invoice_line.id in ignored_ids):
